• About
  • Sponsor
  • grep::cpan
  • Recent
  • FAQ
  • Tools
  • API
    • Identities
    • Profile
    • Favorites
    • Logout
    • GitHub
    • Google
  • 08 Jun 2016 07:00:07 UTC
  • Distribution: Mojo-WebSocketProxy
  • Source (raw)
  • Browse (raw)
  • Changes
  • Homepage
  • How to Contribute
  • Repository
  • Issues (12)
  • Testers (275 / 0 / 46)
  • Kwalitee Kwalitee Score
  • Bus factor: 2
  • 75.80% Coverage
  • License: unknown
  • Perl: v5.14.0
  • Activity
  • Activity Graph
    24 month
  • Tools
  • Download (14.05KB)
  • MetaCPAN Explorer
  • Permissions
  • Subscribe to distribution
    • Dependencies
    • Class::Method::Modifiers
    • Data::UUID
    • Guard
    • JSON
    • MojoX::JSON::RPC
    • Mojolicious
    • Test::MockModule
    • Test::MockObject
    • Test::Mojo
    • Test::More
    • Test::Simple
    • Time::Out
    • and possibly others

    • Reverse dependencies
    • CPAN Testers List
    • Dependency graph
  • Permalinks
  • This version
  • Latest version
  • ++ed by:
    FLORIAN POTATOGIM
    2 PAUSE users
  • Authored by: BINARY
    • Binary.com (binary@cpan.org)
    • Evgeniy Vostrov
Binary.com  / 
Mojo-WebSocketProxy-0.01
River stage one • 1 direct dependent • 1 total dependent
⭐ Starred 1 GitHub stars
/ Mojo::WebSocketProxy::Parser
Contents
  • NAME
  • DESCRIPTION
  • SEE ALSO

NAME

Mojo::WebSocketProxy::Parser

DESCRIPTION

This module using for parse JSON websocket messages.

SEE ALSO

Mojolicious::Plugin::WebSocketProxy, Mojo::WebSocketProxy, Mojo::WebSocketProxy::CallingEngine, Mojo::WebSocketProxy::Dispatcher, Mojo::WebSocketProxy::Config Mojo::WebSocketProxy::Parser

Module Install Instructions

To install Mojo::WebSocketProxy, copy and paste the appropriate command in to your terminal.

cpanm

cpanm Mojo::WebSocketProxy

CPAN shell

perl -MCPAN -e shell
install Mojo::WebSocketProxy

For more information on module installation, please visit the detailed CPAN module installation guide.

Close
MetaCPAN
About
Sponsor
grep::cpan
Recent
FAQ
Tools
API
Perl.org
Bytemark Datadog Deriv Elastic Fastly
Geolytica IBAN Liquid Web OpenCage The Perl and Raku Foundation